@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,12 +33,13 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.documentai_v1beta2.types import document
-from google.cloud.documentai_v1beta2.types import document_understanding
 from google.rpc import status_pb2  # type: ignore
-from .transports.base import DocumentUnderstandingServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DocumentUnderstandingServiceGrpcAsyncIOTransport
+
+from google.cloud.documentai_v1beta2.types import document, document_understanding
+
 from .client import DocumentUnderstandingServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, DocumentUnderstandingServiceTransport
+from .transports.grpc_asyncio import DocumentUnderstandingServiceGrpcAsyncIOTransport
 
 
 class DocumentUnderstandingServiceAsyncClient:
@@ -227,14 +228,13 @@ class DocumentUnderstandingServiceAsyncClient:
         r"""LRO endpoint to batch process many documents. The output is
         written to Cloud Storage as JSON in the [Document] format.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta2
 
-            def sample_batch_process_documents():
+            async def sample_batch_process_documents():
                 # Create a client
-                client = documentai_v1beta2.DocumentUnderstandingServiceClient()
+                client = documentai_v1beta2.DocumentUnderstandingServiceAsyncClient()
 
                 # Initialize request argument(s)
                 requests = documentai_v1beta2.ProcessDocumentRequest()
@@ -250,7 +250,7 @@ class DocumentUnderstandingServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -323,7 +323,12 @@ class DocumentUnderstandingServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -350,9 +355,9 @@ class DocumentUnderstandingServiceAsyncClient:
 
             from google.cloud import documentai_v1beta2
 
-            def sample_process_document():
+            async def sample_process_document():
                 # Create a client
-                client = documentai_v1beta2.DocumentUnderstandingServiceClient()
+                client = documentai_v1beta2.DocumentUnderstandingServiceAsyncClient()
 
                 # Initialize request argument(s)
                 input_config = documentai_v1beta2.InputConfig()
@@ -364,7 +369,7 @@ class DocumentUnderstandingServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.process_document(request=request)
+                response = await client.process_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -417,7 +422,12 @@ class DocumentUnderstandingServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
