@@ -13,15 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.rpc import status_pb2  # type: ignore
+from google.type import color_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.documentai_v1beta2.types import geometry
-from google.rpc import status_pb2  # type: ignore
-from google.type import color_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
-    package="google.cloud.documentai.v1beta2", manifest={"Document",},
+    package="google.cloud.documentai.v1beta2",
+    manifest={
+        "Document",
+    },
 )
 
 
@@ -105,9 +107,18 @@ class Document(proto.Message):
                 in the overall document global text.
         """
 
-        shard_index = proto.Field(proto.INT64, number=1,)
-        shard_count = proto.Field(proto.INT64, number=2,)
-        text_offset = proto.Field(proto.INT64, number=3,)
+        shard_index = proto.Field(
+            proto.INT64,
+            number=1,
+        )
+        shard_count = proto.Field(
+            proto.INT64,
+            number=2,
+        )
+        text_offset = proto.Field(
+            proto.INT64,
+            number=3,
+        )
 
     class Label(proto.Message):
         r"""Label attaches schema information and/or other metadata to segments
@@ -139,9 +150,19 @@ class Document(proto.Message):
                 assignment.
         """
 
-        automl_model = proto.Field(proto.STRING, number=2, oneof="source",)
-        name = proto.Field(proto.STRING, number=1,)
-        confidence = proto.Field(proto.FLOAT, number=3,)
+        automl_model = proto.Field(
+            proto.STRING,
+            number=2,
+            oneof="source",
+        )
+        name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        confidence = proto.Field(
+            proto.FLOAT,
+            number=3,
+        )
 
     class Style(proto.Message):
         r"""Annotation for common text style attributes. This adheres to
@@ -179,21 +200,46 @@ class Document(proto.Message):
                     (in, px, pt, etc.).
             """
 
-            size = proto.Field(proto.FLOAT, number=1,)
-            unit = proto.Field(proto.STRING, number=2,)
+            size = proto.Field(
+                proto.FLOAT,
+                number=1,
+            )
+            unit = proto.Field(
+                proto.STRING,
+                number=2,
+            )
 
         text_anchor = proto.Field(
-            proto.MESSAGE, number=1, message="Document.TextAnchor",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor",
+        )
+        color = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message=color_pb2.Color,
         )
-        color = proto.Field(proto.MESSAGE, number=2, message=color_pb2.Color,)
         background_color = proto.Field(
-            proto.MESSAGE, number=3, message=color_pb2.Color,
+            proto.MESSAGE,
+            number=3,
+            message=color_pb2.Color,
+        )
+        font_weight = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        text_style = proto.Field(
+            proto.STRING,
+            number=5,
+        )
+        text_decoration = proto.Field(
+            proto.STRING,
+            number=6,
         )
-        font_weight = proto.Field(proto.STRING, number=4,)
-        text_style = proto.Field(proto.STRING, number=5,)
-        text_decoration = proto.Field(proto.STRING, number=6,)
         font_size = proto.Field(
-            proto.MESSAGE, number=7, message="Document.Style.FontSize",
+            proto.MESSAGE,
+            number=7,
+            message="Document.Style.FontSize",
         )
 
     class Page(proto.Message):
@@ -254,9 +300,18 @@ class Document(proto.Message):
                     Dimension unit.
             """
 
-            width = proto.Field(proto.FLOAT, number=1,)
-            height = proto.Field(proto.FLOAT, number=2,)
-            unit = proto.Field(proto.STRING, number=3,)
+            width = proto.Field(
+                proto.FLOAT,
+                number=1,
+            )
+            height = proto.Field(
+                proto.FLOAT,
+                number=2,
+            )
+            unit = proto.Field(
+                proto.STRING,
+                number=3,
+            )
 
         class Layout(proto.Message):
             r"""Visual element describing a layout unit on a page.
@@ -291,16 +346,28 @@ class Document(proto.Message):
                 PAGE_LEFT = 4
 
             text_anchor = proto.Field(
-                proto.MESSAGE, number=1, message="Document.TextAnchor",
+                proto.MESSAGE,
+                number=1,
+                message="Document.TextAnchor",
+            )
+            confidence = proto.Field(
+                proto.FLOAT,
+                number=2,
             )
-            confidence = proto.Field(proto.FLOAT, number=2,)
             bounding_poly = proto.Field(
-                proto.MESSAGE, number=3, message=geometry.BoundingPoly,
+                proto.MESSAGE,
+                number=3,
+                message=geometry.BoundingPoly,
             )
             orientation = proto.Field(
-                proto.ENUM, number=4, enum="Document.Page.Layout.Orientation",
+                proto.ENUM,
+                number=4,
+                enum="Document.Page.Layout.Orientation",
+            )
+            id = proto.Field(
+                proto.STRING,
+                number=5,
             )
-            id = proto.Field(proto.STRING, number=5,)
 
         class Block(proto.Message):
             r"""A block has a set of lines (collected into paragraphs) that
@@ -317,10 +384,14 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
 
         class Paragraph(proto.Message):
@@ -338,10 +409,14 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
 
         class Line(proto.Message):
@@ -360,10 +435,14 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.DetectedLanguage",
             )
 
         class Token(proto.Message):
@@ -399,17 +478,25 @@ class Document(proto.Message):
                     HYPHEN = 3
 
                 type_ = proto.Field(
-                    proto.ENUM, number=1, enum="Document.Page.Token.DetectedBreak.Type",
+                    proto.ENUM,
+                    number=1,
+                    enum="Document.Page.Token.DetectedBreak.Type",
                 )
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             detected_break = proto.Field(
-                proto.MESSAGE, number=2, message="Document.Page.Token.DetectedBreak",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.Token.DetectedBreak",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.DetectedLanguage",
             )
 
         class VisualElement(proto.Message):
@@ -430,11 +517,18 @@ class Document(proto.Message):
             """
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
+            )
+            type_ = proto.Field(
+                proto.STRING,
+                number=2,
             )
-            type_ = proto.Field(proto.STRING, number=2,)
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.DetectedLanguage",
             )
 
         class Table(proto.Message):
@@ -463,7 +557,9 @@ class Document(proto.Message):
                 """
 
                 cells = proto.RepeatedField(
-                    proto.MESSAGE, number=1, message="Document.Page.Table.TableCell",
+                    proto.MESSAGE,
+                    number=1,
+                    message="Document.Page.Table.TableCell",
                 )
 
             class TableCell(proto.Message):
@@ -484,25 +580,43 @@ class Document(proto.Message):
                 """
 
                 layout = proto.Field(
-                    proto.MESSAGE, number=1, message="Document.Page.Layout",
+                    proto.MESSAGE,
+                    number=1,
+                    message="Document.Page.Layout",
+                )
+                row_span = proto.Field(
+                    proto.INT32,
+                    number=2,
+                )
+                col_span = proto.Field(
+                    proto.INT32,
+                    number=3,
                 )
-                row_span = proto.Field(proto.INT32, number=2,)
-                col_span = proto.Field(proto.INT32, number=3,)
                 detected_languages = proto.RepeatedField(
-                    proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+                    proto.MESSAGE,
+                    number=4,
+                    message="Document.Page.DetectedLanguage",
                 )
 
             layout = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             header_rows = proto.RepeatedField(
-                proto.MESSAGE, number=2, message="Document.Page.Table.TableRow",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.Table.TableRow",
             )
             body_rows = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.Table.TableRow",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.Table.TableRow",
             )
             detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=4,
+                message="Document.Page.DetectedLanguage",
             )
 
         class FormField(proto.Message):
@@ -542,20 +656,37 @@ class Document(proto.Message):
             """
 
             field_name = proto.Field(
-                proto.MESSAGE, number=1, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=1,
+                message="Document.Page.Layout",
             )
             field_value = proto.Field(
-                proto.MESSAGE, number=2, message="Document.Page.Layout",
+                proto.MESSAGE,
+                number=2,
+                message="Document.Page.Layout",
             )
             name_detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=3, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=3,
+                message="Document.Page.DetectedLanguage",
             )
             value_detected_languages = proto.RepeatedField(
-                proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+                proto.MESSAGE,
+                number=4,
+                message="Document.Page.DetectedLanguage",
+            )
+            value_type = proto.Field(
+                proto.STRING,
+                number=5,
+            )
+            corrected_key_text = proto.Field(
+                proto.STRING,
+                number=6,
+            )
+            corrected_value_text = proto.Field(
+                proto.STRING,
+                number=7,
             )
-            value_type = proto.Field(proto.STRING, number=5,)
-            corrected_key_text = proto.Field(proto.STRING, number=6,)
-            corrected_value_text = proto.Field(proto.STRING, number=7,)
 
         class DetectedLanguage(proto.Message):
             r"""Detected language for a structural component.
@@ -569,37 +700,68 @@ class Document(proto.Message):
                     Confidence of detected language. Range [0, 1].
             """
 
-            language_code = proto.Field(proto.STRING, number=1,)
-            confidence = proto.Field(proto.FLOAT, number=2,)
+            language_code = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            confidence = proto.Field(
+                proto.FLOAT,
+                number=2,
+            )
 
-        page_number = proto.Field(proto.INT32, number=1,)
+        page_number = proto.Field(
+            proto.INT32,
+            number=1,
+        )
         dimension = proto.Field(
-            proto.MESSAGE, number=2, message="Document.Page.Dimension",
+            proto.MESSAGE,
+            number=2,
+            message="Document.Page.Dimension",
+        )
+        layout = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message="Document.Page.Layout",
         )
-        layout = proto.Field(proto.MESSAGE, number=3, message="Document.Page.Layout",)
         detected_languages = proto.RepeatedField(
-            proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
+            proto.MESSAGE,
+            number=4,
+            message="Document.Page.DetectedLanguage",
         )
         blocks = proto.RepeatedField(
-            proto.MESSAGE, number=5, message="Document.Page.Block",
+            proto.MESSAGE,
+            number=5,
+            message="Document.Page.Block",
         )
         paragraphs = proto.RepeatedField(
-            proto.MESSAGE, number=6, message="Document.Page.Paragraph",
+            proto.MESSAGE,
+            number=6,
+            message="Document.Page.Paragraph",
         )
         lines = proto.RepeatedField(
-            proto.MESSAGE, number=7, message="Document.Page.Line",
+            proto.MESSAGE,
+            number=7,
+            message="Document.Page.Line",
         )
         tokens = proto.RepeatedField(
-            proto.MESSAGE, number=8, message="Document.Page.Token",
+            proto.MESSAGE,
+            number=8,
+            message="Document.Page.Token",
         )
         visual_elements = proto.RepeatedField(
-            proto.MESSAGE, number=9, message="Document.Page.VisualElement",
+            proto.MESSAGE,
+            number=9,
+            message="Document.Page.VisualElement",
         )
         tables = proto.RepeatedField(
-            proto.MESSAGE, number=10, message="Document.Page.Table",
+            proto.MESSAGE,
+            number=10,
+            message="Document.Page.Table",
         )
         form_fields = proto.RepeatedField(
-            proto.MESSAGE, number=11, message="Document.Page.FormField",
+            proto.MESSAGE,
+            number=11,
+            message="Document.Page.FormField",
         )
 
     class Entity(proto.Message):
@@ -611,7 +773,7 @@ class Document(proto.Message):
                 Provenance of the entity. Text anchor indexing into the
                 [Document.text][google.cloud.documentai.v1beta2.Document.text].
             type_ (str):
-                Entity type from a schema e.g. ``Address``.
+                Required. Entity type from a schema e.g. ``Address``.
             mention_text (str):
                 Text value in the document e.g. ``1600 Amphitheatre Pkwy``.
             mention_id (str):
@@ -626,26 +788,37 @@ class Document(proto.Message):
             id (str):
                 Optional. Canonical id. This will be a unique
                 value in the entity list for this document.
-            bounding_poly_for_demo_frontend (google.cloud.documentai_v1beta2.types.BoundingPoly):
-                Optional. Temporary field to store the
-                bounding poly for short-term POCs. Used by the
-                frontend only. Do not use before you talk to
-                ybo@ and lukasr@.
         """
 
         text_anchor = proto.Field(
-            proto.MESSAGE, number=1, message="Document.TextAnchor",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor",
+        )
+        type_ = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        mention_text = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        mention_id = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        confidence = proto.Field(
+            proto.FLOAT,
+            number=5,
         )
-        type_ = proto.Field(proto.STRING, number=2,)
-        mention_text = proto.Field(proto.STRING, number=3,)
-        mention_id = proto.Field(proto.STRING, number=4,)
-        confidence = proto.Field(proto.FLOAT, number=5,)
         page_anchor = proto.Field(
-            proto.MESSAGE, number=6, message="Document.PageAnchor",
+            proto.MESSAGE,
+            number=6,
+            message="Document.PageAnchor",
         )
-        id = proto.Field(proto.STRING, number=7,)
-        bounding_poly_for_demo_frontend = proto.Field(
-            proto.MESSAGE, number=8, message=geometry.BoundingPoly,
+        id = proto.Field(
+            proto.STRING,
+            number=7,
         )
 
     class EntityRelation(proto.Message):
@@ -661,9 +834,18 @@ class Document(proto.Message):
                 Relationship description.
         """
 
-        subject_id = proto.Field(proto.STRING, number=1,)
-        object_id = proto.Field(proto.STRING, number=2,)
-        relation = proto.Field(proto.STRING, number=3,)
+        subject_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        object_id = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        relation = proto.Field(
+            proto.STRING,
+            number=3,
+        )
 
     class TextAnchor(proto.Message):
         r"""Text reference indexing into the
@@ -696,13 +878,24 @@ class Document(proto.Message):
                     [Document.text][google.cloud.documentai.v1beta2.Document.text].
             """
 
-            start_index = proto.Field(proto.INT64, number=1,)
-            end_index = proto.Field(proto.INT64, number=2,)
+            start_index = proto.Field(
+                proto.INT64,
+                number=1,
+            )
+            end_index = proto.Field(
+                proto.INT64,
+                number=2,
+            )
 
         text_segments = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="Document.TextAnchor.TextSegment",
+            proto.MESSAGE,
+            number=1,
+            message="Document.TextAnchor.TextSegment",
+        )
+        content = proto.Field(
+            proto.STRING,
+            number=2,
         )
-        content = proto.Field(proto.STRING, number=2,)
 
     class PageAnchor(proto.Message):
         r"""Referencing elements in
@@ -746,29 +939,79 @@ class Document(proto.Message):
                 TABLE = 6
                 FORM_FIELD = 7
 
-            page = proto.Field(proto.INT64, number=1,)
+            page = proto.Field(
+                proto.INT64,
+                number=1,
+            )
             layout_type = proto.Field(
-                proto.ENUM, number=2, enum="Document.PageAnchor.PageRef.LayoutType",
+                proto.ENUM,
+                number=2,
+                enum="Document.PageAnchor.PageRef.LayoutType",
+            )
+            layout_id = proto.Field(
+                proto.STRING,
+                number=3,
             )
-            layout_id = proto.Field(proto.STRING, number=3,)
 
         page_refs = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="Document.PageAnchor.PageRef",
+            proto.MESSAGE,
+            number=1,
+            message="Document.PageAnchor.PageRef",
         )
 
-    uri = proto.Field(proto.STRING, number=1, oneof="source",)
-    content = proto.Field(proto.BYTES, number=2, oneof="source",)
-    mime_type = proto.Field(proto.STRING, number=3,)
-    text = proto.Field(proto.STRING, number=4,)
-    text_styles = proto.RepeatedField(proto.MESSAGE, number=5, message=Style,)
-    pages = proto.RepeatedField(proto.MESSAGE, number=6, message=Page,)
-    entities = proto.RepeatedField(proto.MESSAGE, number=7, message=Entity,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="source",
+    )
+    content = proto.Field(
+        proto.BYTES,
+        number=2,
+        oneof="source",
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    text = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    text_styles = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=Style,
+    )
+    pages = proto.RepeatedField(
+        proto.MESSAGE,
+        number=6,
+        message=Page,
+    )
+    entities = proto.RepeatedField(
+        proto.MESSAGE,
+        number=7,
+        message=Entity,
+    )
     entity_relations = proto.RepeatedField(
-        proto.MESSAGE, number=8, message=EntityRelation,
+        proto.MESSAGE,
+        number=8,
+        message=EntityRelation,
+    )
+    shard_info = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message=ShardInfo,
+    )
+    labels = proto.RepeatedField(
+        proto.MESSAGE,
+        number=11,
+        message=Label,
+    )
+    error = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=status_pb2.Status,
     )
-    shard_info = proto.Field(proto.MESSAGE, number=9, message=ShardInfo,)
-    labels = proto.RepeatedField(proto.MESSAGE, number=11, message=Label,)
-    error = proto.Field(proto.MESSAGE, number=10, message=status_pb2.Status,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
