@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,17 +33,18 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.documentai_v1beta3.services.document_processor_service import pagers
-from google.cloud.documentai_v1beta3.types import document
-from google.cloud.documentai_v1beta3.types import document_processor_service
+from google.cloud.documentai_v1beta3.types import document, document_processor_service
 from google.cloud.documentai_v1beta3.types import processor
 from google.cloud.documentai_v1beta3.types import processor as gcd_processor
 from google.cloud.documentai_v1beta3.types import processor_type
-from google.protobuf import empty_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
+
 from .client import DocumentProcessorServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, DocumentProcessorServiceTransport
+from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
 
 
 class DocumentProcessorServiceAsyncClient:
@@ -249,9 +250,9 @@ class DocumentProcessorServiceAsyncClient:
 
             from google.cloud import documentai_v1beta3
 
-            def sample_process_document():
+            async def sample_process_document():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 inline_document = documentai_v1beta3.Document()
@@ -263,7 +264,7 @@ class DocumentProcessorServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.process_document(request=request)
+                response = await client.process_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -333,7 +334,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -350,14 +356,13 @@ class DocumentProcessorServiceAsyncClient:
         r"""LRO endpoint to batch process many documents. The output is
         written to Cloud Storage as JSON in the [Document] format.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
 
-            def sample_batch_process_documents():
+            async def sample_batch_process_documents():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.BatchProcessRequest(
@@ -369,7 +374,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -442,7 +447,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -472,9 +482,9 @@ class DocumentProcessorServiceAsyncClient:
 
             from google.cloud import documentai_v1beta3
 
-            def sample_fetch_processor_types():
+            async def sample_fetch_processor_types():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.FetchProcessorTypesRequest(
@@ -482,7 +492,7 @@ class DocumentProcessorServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.fetch_processor_types(request=request)
+                response = await client.fetch_processor_types(request=request)
 
                 # Handle the response
                 print(response)
@@ -543,7 +553,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -563,9 +578,9 @@ class DocumentProcessorServiceAsyncClient:
 
             from google.cloud import documentai_v1beta3
 
-            def sample_list_processors():
+            async def sample_list_processors():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.ListProcessorsRequest(
@@ -576,7 +591,7 @@ class DocumentProcessorServiceAsyncClient:
                 page_result = client.list_processors(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -638,12 +653,20 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListProcessorsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -663,14 +686,13 @@ class DocumentProcessorServiceAsyncClient:
         user chose. The processor will be at "ENABLED" state by
         default after its creation.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
 
-            def sample_create_processor():
+            async def sample_create_processor():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.CreateProcessorRequest(
@@ -678,7 +700,7 @@ class DocumentProcessorServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_processor(request=request)
+                response = await client.create_processor(request=request)
 
                 # Handle the response
                 print(response)
@@ -754,7 +776,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -772,14 +799,13 @@ class DocumentProcessorServiceAsyncClient:
         artifacts if it was enabled and then deletes all
         artifacts associated with this processor.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
 
-            def sample_delete_processor():
+            async def sample_delete_processor():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.DeleteProcessorRequest(
@@ -791,7 +817,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -864,7 +890,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -891,9 +922,9 @@ class DocumentProcessorServiceAsyncClient:
 
             from google.cloud import documentai_v1beta3
 
-            def sample_enable_processor():
+            async def sample_enable_processor():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.EnableProcessorRequest(
@@ -905,7 +936,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -947,7 +978,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -974,9 +1010,9 @@ class DocumentProcessorServiceAsyncClient:
 
             from google.cloud import documentai_v1beta3
 
-            def sample_disable_processor():
+            async def sample_disable_processor():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1beta3.DisableProcessorRequest(
@@ -988,7 +1024,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1030,7 +1066,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1055,14 +1096,13 @@ class DocumentProcessorServiceAsyncClient:
         r"""Send a document for Human Review. The input document
         should be processed by the specified processor.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
 
-            def sample_review_document():
+            async def sample_review_document():
                 # Create a client
-                client = documentai_v1beta3.DocumentProcessorServiceClient()
+                client = documentai_v1beta3.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 inline_document = documentai_v1beta3.Document()
@@ -1078,7 +1118,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1154,7 +1194,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
