@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,15 +36,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.documentai_v1beta3.services.document_processor_service import pagers
-from google.cloud.documentai_v1beta3.types import document
-from google.cloud.documentai_v1beta3.types import document_processor_service
+from google.cloud.documentai_v1beta3.types import document, document_processor_service
 from google.cloud.documentai_v1beta3.types import processor
 from google.cloud.documentai_v1beta3.types import processor as gcd_processor
 from google.cloud.documentai_v1beta3.types import processor_type
-from google.protobuf import empty_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, DocumentProcessorServiceTransport
 from .transports.grpc import DocumentProcessorServiceGrpcTransport
 from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
 
@@ -64,7 +65,8 @@ class DocumentProcessorServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = DocumentProcessorServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[DocumentProcessorServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -175,10 +177,16 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return self._transport
 
     @staticmethod
-    def human_review_config_path(project: str, location: str, processor: str,) -> str:
+    def human_review_config_path(
+        project: str,
+        location: str,
+        processor: str,
+    ) -> str:
         """Returns a fully-qualified human_review_config string."""
         return "projects/{project}/locations/{location}/processors/{processor}/humanReviewConfig".format(
-            project=project, location=location, processor=processor,
+            project=project,
+            location=location,
+            processor=processor,
         )
 
     @staticmethod
@@ -191,10 +199,16 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def processor_path(project: str, location: str, processor: str,) -> str:
+    def processor_path(
+        project: str,
+        location: str,
+        processor: str,
+    ) -> str:
         """Returns a fully-qualified processor string."""
         return "projects/{project}/locations/{location}/processors/{processor}".format(
-            project=project, location=location, processor=processor,
+            project=project,
+            location=location,
+            processor=processor,
         )
 
     @staticmethod
@@ -207,10 +221,16 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def processor_type_path(project: str, location: str, processor_type: str,) -> str:
+    def processor_type_path(
+        project: str,
+        location: str,
+        processor_type: str,
+    ) -> str:
         """Returns a fully-qualified processor_type string."""
         return "projects/{project}/locations/{location}/processorTypes/{processor_type}".format(
-            project=project, location=location, processor_type=processor_type,
+            project=project,
+            location=location,
+            processor_type=processor_type,
         )
 
     @staticmethod
@@ -223,7 +243,9 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -236,9 +258,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -247,9 +273,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -258,9 +288,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -269,10 +303,14 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -535,7 +573,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -552,7 +595,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""LRO endpoint to batch process many documents. The output is
         written to Cloud Storage as JSON in the [Document] format.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
@@ -634,7 +676,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -737,7 +784,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -832,12 +884,20 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListProcessorsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -857,7 +917,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         user chose. The processor will be at "ENABLED" state by
         default after its creation.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
@@ -948,7 +1007,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -966,7 +1030,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         artifacts if it was enabled and then deletes all
         artifacts associated with this processor.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
@@ -1058,7 +1121,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1142,7 +1210,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1226,7 +1299,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1251,7 +1329,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Send a document for Human Review. The input document
         should be processed by the specified processor.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1beta3
@@ -1340,7 +1417,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
