@@ -15,20 +15,19 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 from google.cloud.documentai_v1beta3.types import document_processor_service
 from google.cloud.documentai_v1beta3.types import processor as gcd_processor
-from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -83,6 +82,7 @@ class DocumentProcessorServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -159,19 +159,29 @@ class DocumentProcessorServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.list_processors: gapic_v1.method.wrap_method(
-                self.list_processors, default_timeout=None, client_info=client_info,
+                self.list_processors,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_processor: gapic_v1.method.wrap_method(
-                self.create_processor, default_timeout=None, client_info=client_info,
+                self.create_processor,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_processor: gapic_v1.method.wrap_method(
-                self.delete_processor, default_timeout=None, client_info=client_info,
+                self.delete_processor,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.enable_processor: gapic_v1.method.wrap_method(
-                self.enable_processor, default_timeout=None, client_info=client_info,
+                self.enable_processor,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.disable_processor: gapic_v1.method.wrap_method(
-                self.disable_processor, default_timeout=None, client_info=client_info,
+                self.disable_processor,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.review_document: gapic_v1.method.wrap_method(
                 self.review_document,
@@ -193,9 +203,9 @@ class DocumentProcessorServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -294,5 +304,9 @@ class DocumentProcessorServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("DocumentProcessorServiceTransport",)
