@@ -13,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 
 from google.cloud.documentai_v1beta3.types import document_processor_service
 from google.cloud.documentai_v1beta3.types import processor as gcd_processor
-from google.longrunning import operations_pb2  # type: ignore
-from .base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, DocumentProcessorServiceTransport
 
 
 class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
@@ -232,8 +230,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -514,5 +511,9 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("DocumentProcessorServiceGrpcTransport",)
