@@ -15,10 +15,13 @@
 #
 import proto  # type: ignore
 
-
 __protobuf__ = proto.module(
     package="google.cloud.documentai.v1beta3",
-    manifest={"Vertex", "NormalizedVertex", "BoundingPoly",},
+    manifest={
+        "Vertex",
+        "NormalizedVertex",
+        "BoundingPoly",
+    },
 )
 
 
@@ -35,8 +38,14 @@ class Vertex(proto.Message):
             image).
     """
 
-    x = proto.Field(proto.INT32, number=1,)
-    y = proto.Field(proto.INT32, number=2,)
+    x = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    y = proto.Field(
+        proto.INT32,
+        number=2,
+    )
 
 
 class NormalizedVertex(proto.Message):
@@ -52,8 +61,14 @@ class NormalizedVertex(proto.Message):
             image).
     """
 
-    x = proto.Field(proto.FLOAT, number=1,)
-    y = proto.Field(proto.FLOAT, number=2,)
+    x = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    y = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
 
 
 class BoundingPoly(proto.Message):
@@ -66,9 +81,15 @@ class BoundingPoly(proto.Message):
             The bounding polygon normalized vertices.
     """
 
-    vertices = proto.RepeatedField(proto.MESSAGE, number=1, message="Vertex",)
+    vertices = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Vertex",
+    )
     normalized_vertices = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="NormalizedVertex",
+        proto.MESSAGE,
+        number=2,
+        message="NormalizedVertex",
     )
 
 
