@@ -13,39 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
+from google.api_core import (
+    future,
+    gapic_v1,
+    grpc_helpers,
+    grpc_helpers_async,
+    operation,
+    operations_v1,
+    path_template,
+)
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import future
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import operation
 from google.api_core import operation_async  # type: ignore
-from google.api_core import operations_v1
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.documentai_v1.services.document_processor_service import (
-    DocumentProcessorServiceAsyncClient,
-)
-from google.cloud.documentai_v1.services.document_processor_service import (
-    DocumentProcessorServiceClient,
-)
-from google.cloud.documentai_v1.services.document_processor_service import transports
-from google.cloud.documentai_v1.types import document
-from google.cloud.documentai_v1.types import document_io
-from google.cloud.documentai_v1.types import document_processor_service
-from google.cloud.documentai_v1.types import geometry
 from google.longrunning import operations_pb2
 from google.oauth2 import service_account
 from google.protobuf import any_pb2  # type: ignore
@@ -58,7 +43,23 @@ from google.type import date_pb2  # type: ignore
 from google.type import datetime_pb2  # type: ignore
 from google.type import money_pb2  # type: ignore
 from google.type import postal_address_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.documentai_v1.services.document_processor_service import (
+    DocumentProcessorServiceAsyncClient,
+    DocumentProcessorServiceClient,
+    transports,
+)
+from google.cloud.documentai_v1.types import (
+    document,
+    document_io,
+    document_processor_service,
+    geometry,
+)
 
 
 def client_cert_source_callback():
@@ -107,21 +108,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class",
-    [DocumentProcessorServiceClient, DocumentProcessorServiceAsyncClient,],
+    "client_class,transport_name",
+    [
+        (DocumentProcessorServiceClient, "grpc"),
+        (DocumentProcessorServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_document_processor_service_client_from_service_account_info(client_class):
+def test_document_processor_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "documentai.googleapis.com:443"
+        assert client.transport._host == ("documentai.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -150,24 +156,33 @@ def test_document_processor_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class",
-    [DocumentProcessorServiceClient, DocumentProcessorServiceAsyncClient,],
+    "client_class,transport_name",
+    [
+        (DocumentProcessorServiceClient, "grpc"),
+        (DocumentProcessorServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_document_processor_service_client_from_service_account_file(client_class):
+def test_document_processor_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "documentai.googleapis.com:443"
+        assert client.transport._host == ("documentai.googleapis.com:443")
 
 
 def test_document_processor_service_client_get_transport_class():
@@ -540,7 +555,9 @@ def test_document_processor_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -681,11 +698,16 @@ def test_document_processor_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [document_processor_service.ProcessRequest, dict,]
+    "request_type",
+    [
+        document_processor_service.ProcessRequest,
+        dict,
+    ],
 )
 def test_process_document(request_type, transport: str = "grpc"):
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -711,7 +733,8 @@ def test_process_document_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -728,7 +751,8 @@ async def test_process_document_async(
     request_type=document_processor_service.ProcessRequest,
 ):
     client = DocumentProcessorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -766,7 +790,7 @@ def test_process_document_field_headers():
     # a field header. Set these to a non-empty value.
     request = document_processor_service.ProcessRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
@@ -780,7 +804,10 @@ def test_process_document_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -793,7 +820,7 @@ async def test_process_document_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = document_processor_service.ProcessRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
@@ -809,7 +836,10 @@ async def test_process_document_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 def test_process_document_flattened():
@@ -823,7 +853,9 @@ def test_process_document_flattened():
         call.return_value = document_processor_service.ProcessResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.process_document(name="name_value",)
+        client.process_document(
+            name="name_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -843,7 +875,8 @@ def test_process_document_flattened_error():
     # fields is an error.
     with pytest.raises(ValueError):
         client.process_document(
-            document_processor_service.ProcessRequest(), name="name_value",
+            document_processor_service.ProcessRequest(),
+            name="name_value",
         )
 
 
@@ -863,7 +896,9 @@ async def test_process_document_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.process_document(name="name_value",)
+        response = await client.process_document(
+            name="name_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -884,16 +919,22 @@ async def test_process_document_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.process_document(
-            document_processor_service.ProcessRequest(), name="name_value",
+            document_processor_service.ProcessRequest(),
+            name="name_value",
         )
 
 
 @pytest.mark.parametrize(
-    "request_type", [document_processor_service.BatchProcessRequest, dict,]
+    "request_type",
+    [
+        document_processor_service.BatchProcessRequest,
+        dict,
+    ],
 )
 def test_batch_process_documents(request_type, transport: str = "grpc"):
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -921,7 +962,8 @@ def test_batch_process_documents_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -940,7 +982,8 @@ async def test_batch_process_documents_async(
     request_type=document_processor_service.BatchProcessRequest,
 ):
     client = DocumentProcessorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -980,7 +1023,7 @@ def test_batch_process_documents_field_headers():
     # a field header. Set these to a non-empty value.
     request = document_processor_service.BatchProcessRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -996,7 +1039,10 @@ def test_batch_process_documents_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1009,7 +1055,7 @@ async def test_batch_process_documents_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = document_processor_service.BatchProcessRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1027,7 +1073,10 @@ async def test_batch_process_documents_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 def test_batch_process_documents_flattened():
@@ -1043,7 +1092,9 @@ def test_batch_process_documents_flattened():
         call.return_value = operations_pb2.Operation(name="operations/op")
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.batch_process_documents(name="name_value",)
+        client.batch_process_documents(
+            name="name_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1063,7 +1114,8 @@ def test_batch_process_documents_flattened_error():
     # fields is an error.
     with pytest.raises(ValueError):
         client.batch_process_documents(
-            document_processor_service.BatchProcessRequest(), name="name_value",
+            document_processor_service.BatchProcessRequest(),
+            name="name_value",
         )
 
 
@@ -1085,7 +1137,9 @@ async def test_batch_process_documents_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.batch_process_documents(name="name_value",)
+        response = await client.batch_process_documents(
+            name="name_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1106,16 +1160,22 @@ async def test_batch_process_documents_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.batch_process_documents(
-            document_processor_service.BatchProcessRequest(), name="name_value",
+            document_processor_service.BatchProcessRequest(),
+            name="name_value",
         )
 
 
 @pytest.mark.parametrize(
-    "request_type", [document_processor_service.ReviewDocumentRequest, dict,]
+    "request_type",
+    [
+        document_processor_service.ReviewDocumentRequest,
+        dict,
+    ],
 )
 def test_review_document(request_type, transport: str = "grpc"):
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1141,7 +1201,8 @@ def test_review_document_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1158,7 +1219,8 @@ async def test_review_document_async(
     request_type=document_processor_service.ReviewDocumentRequest,
 ):
     client = DocumentProcessorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1196,7 +1258,7 @@ def test_review_document_field_headers():
     # a field header. Set these to a non-empty value.
     request = document_processor_service.ReviewDocumentRequest()
 
-    request.human_review_config = "human_review_config/value"
+    request.human_review_config = "human_review_config_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.review_document), "__call__") as call:
@@ -1212,7 +1274,7 @@ def test_review_document_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "human_review_config=human_review_config/value",
+        "human_review_config=human_review_config_value",
     ) in kw["metadata"]
 
 
@@ -1226,7 +1288,7 @@ async def test_review_document_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = document_processor_service.ReviewDocumentRequest()
 
-    request.human_review_config = "human_review_config/value"
+    request.human_review_config = "human_review_config_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.review_document), "__call__") as call:
@@ -1244,7 +1306,7 @@ async def test_review_document_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "human_review_config=human_review_config/value",
+        "human_review_config=human_review_config_value",
     ) in kw["metadata"]
 
 
@@ -1259,7 +1321,9 @@ def test_review_document_flattened():
         call.return_value = operations_pb2.Operation(name="operations/op")
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.review_document(human_review_config="human_review_config_value",)
+        client.review_document(
+            human_review_config="human_review_config_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1335,7 +1399,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DocumentProcessorServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1356,7 +1421,8 @@ def test_credentials_transport_error():
     options.api_key = "api_key"
     with pytest.raises(ValueError):
         client = DocumentProcessorServiceClient(
-            client_options=options, transport=transport,
+            client_options=options,
+            transport=transport,
         )
 
     # It is an error to provide an api_key and a credential.
@@ -1373,7 +1439,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DocumentProcessorServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1416,13 +1483,27 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = DocumentProcessorServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = DocumentProcessorServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
     assert isinstance(
-        client.transport, transports.DocumentProcessorServiceGrpcTransport,
+        client.transport,
+        transports.DocumentProcessorServiceGrpcTransport,
     )
 
 
@@ -1464,6 +1545,14 @@ def test_document_processor_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.operations_client
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_document_processor_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1475,7 +1564,8 @@ def test_document_processor_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DocumentProcessorServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1612,24 +1702,40 @@ def test_document_processor_service_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_document_processor_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_document_processor_service_host_no_port(transport_name):
     client = DocumentProcessorServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="documentai.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "documentai.googleapis.com:443"
+    assert client.transport._host == ("documentai.googleapis.com:443")
 
 
-def test_document_processor_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_document_processor_service_host_with_port(transport_name):
     client = DocumentProcessorServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="documentai.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "documentai.googleapis.com:8000"
+    assert client.transport._host == ("documentai.googleapis.com:8000")
 
 
 def test_document_processor_service_grpc_transport_channel():
@@ -1637,7 +1743,8 @@ def test_document_processor_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DocumentProcessorServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1649,7 +1756,8 @@ def test_document_processor_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DocumentProcessorServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1758,12 +1866,16 @@ def test_document_processor_service_transport_channel_mtls_with_adc(transport_cl
 
 def test_document_processor_service_grpc_lro_client():
     client = DocumentProcessorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1771,12 +1883,16 @@ def test_document_processor_service_grpc_lro_client():
 
 def test_document_processor_service_grpc_lro_async_client():
     client = DocumentProcessorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1787,7 +1903,9 @@ def test_human_review_config_path():
     location = "clam"
     processor = "whelk"
     expected = "projects/{project}/locations/{location}/processors/{processor}/humanReviewConfig".format(
-        project=project, location=location, processor=processor,
+        project=project,
+        location=location,
+        processor=processor,
     )
     actual = DocumentProcessorServiceClient.human_review_config_path(
         project, location, processor
@@ -1813,7 +1931,9 @@ def test_processor_path():
     location = "mussel"
     processor = "winkle"
     expected = "projects/{project}/locations/{location}/processors/{processor}".format(
-        project=project, location=location, processor=processor,
+        project=project,
+        location=location,
+        processor=processor,
     )
     actual = DocumentProcessorServiceClient.processor_path(project, location, processor)
     assert expected == actual
@@ -1854,7 +1974,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = DocumentProcessorServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1872,7 +1994,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = DocumentProcessorServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1890,7 +2014,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = DocumentProcessorServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1910,7 +2036,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = DocumentProcessorServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1935,7 +2062,8 @@ def test_client_with_default_client_info():
         transports.DocumentProcessorServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = DocumentProcessorServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1944,7 +2072,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = DocumentProcessorServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1952,7 +2081,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = DocumentProcessorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
