@@ -13,44 +13,43 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import os
-import mock
-
-import grpc
-from grpc.experimental import aio
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+import os
 
+from google.api_core import (
+    future,
+    gapic_v1,
+    grpc_helpers,
+    grpc_helpers_async,
+    operation,
+    operations_v1,
+    path_template,
+)
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import future
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import operation
 from google.api_core import operation_async  # type: ignore
-from google.api_core import operations_v1
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.documentai_v1beta2.services.document_understanding_service import (
-    DocumentUnderstandingServiceAsyncClient,
-)
-from google.cloud.documentai_v1beta2.services.document_understanding_service import (
-    DocumentUnderstandingServiceClient,
-)
-from google.cloud.documentai_v1beta2.services.document_understanding_service import (
-    transports,
-)
-from google.cloud.documentai_v1beta2.types import document
-from google.cloud.documentai_v1beta2.types import document_understanding
-from google.cloud.documentai_v1beta2.types import geometry
 from google.longrunning import operations_pb2
 from google.oauth2 import service_account
 from google.rpc import status_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+import mock
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.documentai_v1beta2.services.document_understanding_service import (
+    DocumentUnderstandingServiceAsyncClient,
+    DocumentUnderstandingServiceClient,
+    transports,
+)
+from google.cloud.documentai_v1beta2.types import (
+    document,
+    document_understanding,
+    geometry,
+)
 
 
 def client_cert_source_callback():
@@ -101,21 +100,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class",
-    [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient,],
+    "client_class,transport_name",
+    [
+        (DocumentUnderstandingServiceClient, "grpc"),
+        (DocumentUnderstandingServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_document_understanding_service_client_from_service_account_info(client_class):
+def test_document_understanding_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "documentai.googleapis.com:443"
+        assert client.transport._host == ("documentai.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -144,24 +148,33 @@ def test_document_understanding_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class",
-    [DocumentUnderstandingServiceClient, DocumentUnderstandingServiceAsyncClient,],
+    "client_class,transport_name",
+    [
+        (DocumentUnderstandingServiceClient, "grpc"),
+        (DocumentUnderstandingServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_document_understanding_service_client_from_service_account_file(client_class):
+def test_document_understanding_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "documentai.googleapis.com:443"
+        assert client.transport._host == ("documentai.googleapis.com:443")
 
 
 def test_document_understanding_service_client_get_transport_class():
@@ -534,7 +547,9 @@ def test_document_understanding_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -675,11 +690,16 @@ def test_document_understanding_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [document_understanding.BatchProcessDocumentsRequest, dict,]
+    "request_type",
+    [
+        document_understanding.BatchProcessDocumentsRequest,
+        dict,
+    ],
 )
 def test_batch_process_documents(request_type, transport: str = "grpc"):
     client = DocumentUnderstandingServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -707,7 +727,8 @@ def test_batch_process_documents_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentUnderstandingServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -726,7 +747,8 @@ async def test_batch_process_documents_async(
     request_type=document_understanding.BatchProcessDocumentsRequest,
 ):
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -766,7 +788,7 @@ def test_batch_process_documents_field_headers():
     # a field header. Set these to a non-empty value.
     request = document_understanding.BatchProcessDocumentsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -782,7 +804,10 @@ def test_batch_process_documents_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -795,7 +820,7 @@ async def test_batch_process_documents_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = document_understanding.BatchProcessDocumentsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -813,7 +838,10 @@ async def test_batch_process_documents_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_batch_process_documents_flattened():
@@ -915,11 +943,16 @@ async def test_batch_process_documents_flattened_error_async():
 
 
 @pytest.mark.parametrize(
-    "request_type", [document_understanding.ProcessDocumentRequest, dict,]
+    "request_type",
+    [
+        document_understanding.ProcessDocumentRequest,
+        dict,
+    ],
 )
 def test_process_document(request_type, transport: str = "grpc"):
     client = DocumentUnderstandingServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -930,7 +963,9 @@ def test_process_document(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = document.Document(
-            mime_type="mime_type_value", text="text_value", uri="uri_value",
+            mime_type="mime_type_value",
+            text="text_value",
+            uri="uri_value",
         )
         response = client.process_document(request)
 
@@ -949,7 +984,8 @@ def test_process_document_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DocumentUnderstandingServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -966,7 +1002,8 @@ async def test_process_document_async(
     request_type=document_understanding.ProcessDocumentRequest,
 ):
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -977,7 +1014,10 @@ async def test_process_document_async(
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            document.Document(mime_type="mime_type_value", text="text_value",)
+            document.Document(
+                mime_type="mime_type_value",
+                text="text_value",
+            )
         )
         response = await client.process_document(request)
 
@@ -1006,7 +1046,7 @@ def test_process_document_field_headers():
     # a field header. Set these to a non-empty value.
     request = document_understanding.ProcessDocumentRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
@@ -1020,7 +1060,10 @@ def test_process_document_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1033,7 +1076,7 @@ async def test_process_document_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = document_understanding.ProcessDocumentRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.process_document), "__call__") as call:
@@ -1047,7 +1090,10 @@ async def test_process_document_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -1057,7 +1103,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DocumentUnderstandingServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1078,7 +1125,8 @@ def test_credentials_transport_error():
     options.api_key = "api_key"
     with pytest.raises(ValueError):
         client = DocumentUnderstandingServiceClient(
-            client_options=options, transport=transport,
+            client_options=options,
+            transport=transport,
         )
 
     # It is an error to provide an api_key and a credential.
@@ -1095,7 +1143,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DocumentUnderstandingServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1138,13 +1187,27 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = DocumentUnderstandingServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = DocumentUnderstandingServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
     assert isinstance(
-        client.transport, transports.DocumentUnderstandingServiceGrpcTransport,
+        client.transport,
+        transports.DocumentUnderstandingServiceGrpcTransport,
     )
 
 
@@ -1185,6 +1248,14 @@ def test_document_understanding_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.operations_client
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_document_understanding_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1196,7 +1267,8 @@ def test_document_understanding_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DocumentUnderstandingServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1336,24 +1408,40 @@ def test_document_understanding_service_grpc_transport_client_cert_source_for_mt
             )
 
 
-def test_document_understanding_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_document_understanding_service_host_no_port(transport_name):
     client = DocumentUnderstandingServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="documentai.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "documentai.googleapis.com:443"
+    assert client.transport._host == ("documentai.googleapis.com:443")
 
 
-def test_document_understanding_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_document_understanding_service_host_with_port(transport_name):
     client = DocumentUnderstandingServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="documentai.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "documentai.googleapis.com:8000"
+    assert client.transport._host == ("documentai.googleapis.com:8000")
 
 
 def test_document_understanding_service_grpc_transport_channel():
@@ -1361,7 +1449,8 @@ def test_document_understanding_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DocumentUnderstandingServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1373,7 +1462,8 @@ def test_document_understanding_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DocumentUnderstandingServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1484,12 +1574,16 @@ def test_document_understanding_service_transport_channel_mtls_with_adc(
 
 def test_document_understanding_service_grpc_lro_client():
     client = DocumentUnderstandingServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1497,12 +1591,16 @@ def test_document_understanding_service_grpc_lro_client():
 
 def test_document_understanding_service_grpc_lro_async_client():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1532,7 +1630,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = DocumentUnderstandingServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1550,7 +1650,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = DocumentUnderstandingServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1568,7 +1670,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = DocumentUnderstandingServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1588,7 +1692,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = DocumentUnderstandingServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1613,7 +1718,8 @@ def test_client_with_default_client_info():
         transports.DocumentUnderstandingServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = DocumentUnderstandingServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1622,7 +1728,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = DocumentUnderstandingServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1630,7 +1737,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = DocumentUnderstandingServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
